**************
Linux Specific
**************

Init Scripts
============
`share/linux/lsb` directory contains LSB-compliant init-files for daemons.

Copy scripts to `/etc/init.d` and configuration file to `/etc/sysconfig`
and create appropriative symlinks.
